@@ -1,5 +1,5 @@
 /* mpdscribble (MPD Client)
- * Copyright (C) 2008-2009 The Music Player Daemon Project
+ * Copyright (C) 2008-2010 The Music Player Daemon Project
  * Copyright (C) 2005-2008 Kuno Woudt <kuno@frob.nl>
  * Project homepage: http://musicpd.org
  
@@ -50,9 +50,10 @@ chomp_length(const char *p)
 	return (int)length;
 }
 
-static const char *log_date(void)
+const char *
+log_date(void)
 {
-	static char buf[20];
+	static char buf[32];
 	time_t t;
 	struct tm *tmp;
 
@@ -63,7 +64,7 @@ static const char *log_date(void)
 		return buf;
 	}
 
-	if (!strftime(buf, sizeof(buf), "%Y/%m/%d %H:%M:%S", tmp)) {
+	if (!strftime(buf, sizeof(buf), "%Y-%m-%dT%H:%M:%S%z", tmp)) {
 		buf[0] = 0;
 		return buf;
 	}
