@@ -1,5 +1,5 @@
 /* mpdscribble (MPD Client)
- * Copyright (C) 2008-2009 The Music Player Daemon Project
+ * Copyright (C) 2008-2010 The Music Player Daemon Project
  * Copyright (C) 2005-2008 Kuno Woudt <kuno@frob.nl>
  * Project homepage: http://musicpd.org
  
@@ -27,4 +27,7 @@ log_init(const char *path, int verbose);
 void
 log_deinit(void);
 
+const char *
+log_date(void);
+
 #endif
